# -*- coding: utf-8 -*-

__title__ = 'djangorestframework-jwt'
__version__ = '1.7.1'
__author__ = 'José Padilla'
__license__ = 'MIT'
__copyright__ = 'Copyright 2014-2015 Blimp LLC'

# Version synonym
VERSION = __version__
